#
# spec file for package lxqt-qtplugin
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-qtplugin
Version:        0.14.0
Release:        lp152.1.7
Summary:        LXQt platform integration plugin for Qt 5
License:        LGPL-2.1-or-later
Group:          System/GUI/LXQt
URL:            http://www.lxqt.org
Source:         https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/lxqt/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.1.0
BuildRequires:  gcc-c++
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libexif-devel
BuildRequires:  lxqt-build-tools-devel >= 0.6.0
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5XdgIconLoader)
BuildRequires:  pkgconfig(dbusmenu-qt5)
BuildRequires:  pkgconfig(lxqt) >= %{version}
%if 0%{?fedora_version}
%requires_eq    qt5-qtbase-gui
%else
%requires_eq    libQt5Gui5
%endif

%description
With this plugin, all Qt-based programs can adopt settings of
LXQt, such as the icon theme.

To use the plugin in Qt5, we have to export the environment
variable QT_QPA_PLATFORMTHEME=lxqt. Then every Qt5 program
can load the theme plugin.
If, for some unknown reasons, the plugin is not loaded, we can
debug the plugin by exporting QT_DEBUG_PLUGINS=1.
Then, Qt5 will print detailed information and error messages
about all plugins in the console when running any Qt5 programs.

%prep
%setup -q

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install

%files
%license LICENSE
%doc AUTHORS README.md
%dir %{_libdir}/qt5/plugins
%dir %{_libdir}/qt5/plugins/platformthemes
%{_libdir}/qt5/plugins/platformthemes/libqtlxqt.so

%changelog
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Dynamically load libfm-qt on demand to create
    the file dialog helper.
  * Don't use automatic string conversions
  * Improved cmake scripting
  - Set cmake_minimum_required to 3.1.0
  - Removed locale compile definitons
  - Removed the superfluous libfm-qt dependency
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * lxqtplatformtheme: Initialize “folowColorScheme” once
  * Fix icon colorizing at startup
  * Remember the view mode
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set an informal patch version
  * Don't export github templates
  * Flag unused vars in onServiceOwnerChanged
  * Fix missing variable declaration
  * Handle QML (as @PCMan suggested)
  * Use mime functions added by @PCMan
  * Loading and saving window/splitter size
  * Central positioning with respect to parent
  * Set window title correctly
  * Qt version conditions
  * Just made it compilable
  * Handle mime-type filters for file dialog. Set custom file dialog labels.
  * Update options properly.
  * Implement a basic file dialog helper using libfm-qt's Fm::FileDialog.
  * Avoid using Qt-specific keywords such as signal/slot and foreach. Instead, use macros.
  * LXQtPlatformTheme: Make Qt use default palette (#22)
  * LXQtPlatformTheme: Add icon FollowColorScheme config (#21)
  * Prevent a possible C++11 range for detach (#20)
  * Use the CMake MODULE library type.
  * LXQtPlatformTheme: Propagate wheelScrollLines
  * LXQtPlatformTheme: Do not provide own palette
  * Fix multiple StatusNotifierItems.
  * Bump year
  * Updates lxqt-build-tools required version
* Sat Mar  4 2017 sfalken@opensuse.org
- Update Source URLs
* Fri Feb 24 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Use lxqt-build-tools
  * Use the new lxqt-build-tools package
  * Remove cpack (#14)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Add Qt5XdgIconLoader as dependency (#13)
  * Update README.md
  * statusnotifieritem: Correctly handle menu
  * Cleaned up licenses
  * Use XdgIconLoader library (#10)
  * xdgIconThemePaths: Use QString::SkipEmptyParts
  * xdgIconThemePaths: Remove duplicated paths
  * Adds $XDG_DATA_HOME to the XdgIconThemePaths
  * Bump year in AUTHORS
- Add keyring
- Require pkgconfig(Qt5XdgIconLoader) instead of pkgconfig(Qt5Xdg)
  because IconLoader has its own package now and got split out
  of libqt5xdg.
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to use cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
* Mon Jan 26 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora Builds
* Thu Dec 25 2014 hrvoje.senjan@gmail.com
- lxqt-qtplugin is using private QPA API, which can, and does break BC
  even in point releases, so we need to hardcode libQt5Gui5 version
* Tue Nov 11 2014 andrea@opensuse.org
- Fixed license tag
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 andrea@opensuse.org
- removed unused build requires
* Tue May 13 2014 andrea@opensuse.org
- spec file clean up
* Mon May 12 2014 sfalken@opensuse.org
- removed fedora spec, split into subproject
  Del: lxqt-qtplugin-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-qtplugin-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-qtplugin-0.7.0.tar.xz
  Del:  _service
* Thu Apr  3 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-qtplugin.spec
  Add: lxqt-qtplugin.changes
